﻿using System.Windows;
using System.Windows.Controls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace LayerVisibleSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;

            WorldMapKitWmsWpfOverlay worldMapKitOverlay = new WorldMapKitWmsWpfOverlay();
            wpfMap1.Overlays.Add(worldMapKitOverlay);

            LayerOverlay customLayerOverlay = new LayerOverlay();
            wpfMap1.Overlays.Add("CustomOverlay", customLayerOverlay);

            ShapeFileFeatureLayer countriesLayer = new ShapeFileFeatureLayer(@"..\..\App_Data\Countries02.shp");
            countriesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            countriesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            countriesLayer.ZoomLevelSet.ZoomLevel02.DefaultAreaStyle = AreaStyles.Country1;
            countriesLayer.ZoomLevelSet.ZoomLevel02.DefaultTextStyle = TextStyles.Country1("CNTRY_NAME");
            countriesLayer.ZoomLevelSet.ZoomLevel02.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level04;

            customLayerOverlay.Layers.Add("Countries", countriesLayer);

            ShapeFileFeatureLayer majorCitiesLayer = new ShapeFileFeatureLayer(@"..\..\App_Data\MajorCities.shp");
            majorCitiesLayer.ZoomLevelSet.ZoomLevel05.DefaultPointStyle = PointStyles.City1;
            majorCitiesLayer.ZoomLevelSet.ZoomLevel05.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level07;

            majorCitiesLayer.ZoomLevelSet.ZoomLevel06.DefaultPointStyle = PointStyles.City1;
            majorCitiesLayer.ZoomLevelSet.ZoomLevel06.DefaultTextStyle = TextStyles.City1("AREANAME");
            majorCitiesLayer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            customLayerOverlay.Layers.Add("MajorCities", majorCitiesLayer);

            wpfMap1.CurrentExtent = new RectangleShape(-122.437392,47.626353,-71.089115,25.787676);
            wpfMap1.Refresh();
        }

        private void CheckBox_Click(object sender, RoutedEventArgs e)
        {
            CheckBox chb = sender as CheckBox;
            string clickedLayerName = chb.Tag.ToString();
            LayerOverlay customLayerOverlay = wpfMap1.Overlays["CustomOverlay"] as LayerOverlay;
            Layer layer = customLayerOverlay.Layers[clickedLayerName];
            layer.IsVisible = chb.IsChecked.GetValueOrDefault();
            wpfMap1.Refresh(customLayerOverlay);
        }
    }
}
